==> hyperdex-1.2.0.tar.gz: hyperdex-1.2.0/daemon/performance_counter.h <==
// Copyright (c) 2013, Cornell University
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice,
//       this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of HyperDex nor the names of its contributors may be
//       used to endorse or promote products derived from this software without
//       specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

#ifndef hyperdex_daemon_performance_counters_h_
#define hyperdex_daemon_performance_counters_h_

// e
#include <e/atomic.h>

BEGIN_HYPERDEX_NAMESPACE

// a threadsafe counter
class performance_counter
{
    public:
        performance_counter() : m_count(0), m_stable(0) {}
        ~performance_counter() throw () {}

    public:
        // increment the counter
        // any number of threads can tap simultaneously
        void tap() { e::atomic::increment_64_nobarrier(&m_count, 1); }
        // any number of threads can call "read" simultaneously
        uint64_t read() { return e::atomic::load_64_nobarrier(&m_count); }

    private:
        performance_counter(const performance_counter&);
        performance_counter& operator = (const performance_counter&);

    private:
        uint64_t m_count;
        uint64_t m_stable;
};

END_HYPERDEX_NAMESPACE

#endif // hyperdex_daemon_performance_counters_h_

==> hyperdex-1.8.1.tar.gz: hyperdex-1.8.1/daemon/performance_counter.h <==
// Copyright (c) 2013, Cornell University
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice,
//       this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright
//       notice, this list of conditions and the following disclaimer in the
//       documentation and/or other materials provided with the distribution.
//     * Neither the name of HyperDex nor the names of its contributors may be
//       used to endorse or promote products derived from this software without
//       specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

#ifndef hyperdex_daemon_performance_counters_h_
#define hyperdex_daemon_performance_counters_h_

// e
#include <e/atomic.h>

BEGIN_HYPERDEX_NAMESPACE

// a threadsafe counter
class performance_counter
{
    public:
        performance_counter() : m_count(0) {}
        ~performance_counter() throw () {}

    public:
        // increment the counter
        // any number of threads can tap simultaneously
        void tap() { e::atomic::increment_64_nobarrier(&m_count, 1); }
        // any number of threads can call "read" simultaneously
        uint64_t read() const { return e::atomic::load_64_nobarrier(&m_count); }

    private:
        performance_counter(const performance_counter&);
        performance_counter& operator = (const performance_counter&);

    private:
        uint64_t m_count;
};

END_HYPERDEX_NAMESPACE

#endif // hyperdex_daemon_performance_counters_h_
